/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import ClayIcon from '@clayui/icon';
import {ClayTooltipProvider} from '@clayui/tooltip';
import Proptypes from 'prop-types';
import React from 'react';

function TooltipText({text}) {
	return (
		<div className="bg-dark">
			<p>{text}</p>
		</div>
	);
}

function TooltipTextRenderer({value}) {
	const {iconSymbol, text} = value;

	return (
		<>
			<ClayTooltipProvider
				contentRenderer={() => <TooltipText text={text} />}
			>
				<span className="tooltip-provider">
					<ClayIcon symbol={iconSymbol} />
				</span>
			</ClayTooltipProvider>
		</>
	);
}

TooltipTextRenderer.defaultProps = {
	value: {
		iconSymbol: 'info-circle',
		text: 'This is a sample text',
	},
};

TooltipTextRenderer.propTypes = {
	value: Proptypes.shape({
		iconSymbol: Proptypes.string,
		text: Proptypes.string,
	}),
};

export default TooltipTextRenderer;
